-- Pull in the wezterm API
local wezterm = require 'wezterm'

-- This will hold the configuration.
local config = wezterm.config_builder()
local act = wezterm.action

-- This is where you actually apply your config choices
config.ssh_domains = {
  {
    -- This name identifies the domain
    name = 'home',
    -- The hostname or address to connect to. Will be used to match settings
    -- from your ssh config file
    remote_address = '192.168.1.20',
    -- The username to use on the remote host
    username = 'anton',
  },
}
config.keys = {
  { key = 'U', mods = 'CTRL|SHIFT', action = act.AttachDomain 'devhost' },
  -- Detaches the domain associated with the current pane
  {
    key = 'D',
    mods = 'CTRL|SHIFT',
    action = act.DetachDomain 'CurrentPaneDomain',
  },
  -- Detaches the "devhost" domain
  {
    key = 'E',
    mods = 'CTRL|SHIFT',
    action = act.DetachDomain { DomainName = 'devhost' },
  },
}
config.window_decorations = "RESIZE | INTEGRATED_BUTTONS"
config.initial_cols = 127
config.initial_rows = 67



-- For example, changing the color scheme: ==>  A!=B
config.color_scheme = 'Galaxy'
config.font = wezterm.font('Jetbrains Mono', { weight = 600 })
config.freetype_load_target = 'Light'
config.font_size = 16
config.line_height = 1.05
config.harfbuzz_features = { 'calt=1', 'clig=0', 'liga=0' }



config.window_padding = {
	left = 0,
	right = 0,
	top = 0,
	bottom = 0,
}


config.window_frame = {
  font = wezterm.font { family = 'Jetbrains Mono', weight = 700 },

  -- The size of the font in the tab bar.
  font_size = 15.0,

  -- The overall background color of the tab bar when
  -- the window is focused
  active_titlebar_bg = '#222222',
  inactive_titlebar_bg = '#000000',
  active_titlebar_fg = '#ffffff',

 border_left_width = '0.5cell',
  border_right_width = '0.5cell',
  border_bottom_height = '0cell',
  border_top_height = '0.1cell',
  border_left_color = '#1c2836',
  border_right_color = '#1c2836',
  border_bottom_color = '#1c2836',
  border_top_color = '#1c2836',

  -- The overall background color of the tab bar when
  -- the window is not focused
}

-- and finally, return the configuration to wezterm
return config
